@@ -92,6 +92,7 @@
 							$_POST['r_delete'] = cleanstr($_POST['r_delete']);
 							$_POST['r_edit'] = cleanstr($_POST['r_edit']);
 							$_POST['r_spam'] = cleanstr($_POST['r_spam']);
+							$_POST['r_edit_smilies'] = cleanstr($_POST['r_edit_smilies']);
 							$_POST['old_password'] = cleanstr($_POST['old_password']);
 							$_POST['new_password_1'] = cleanstr($_POST['new_password_1']);
 							$_POST['new_password_2'] = cleanstr($_POST['new_password_2']);
@@ -166,10 +167,11 @@
 											`r_deactivate` = '".$_POST['r_deactivate']."',
 											`r_delete` = '".$_POST['r_delete']."',
 											`r_edit` = '".$_POST['r_edit']."',
+											`r_edit_smilies` = '".$_POST['r_edit_smilies']."',
 											`r_spam` = '".$_POST['r_spam']."'
 											WHERE ID=".secure_value($_GET['id'])." LIMIT 1";
 
-									if ( @mysql_query($sql, $link) or die ("(edit_user.inc.php) Error, Line 171: ".mysql_error()) )
+									if ( @mysql_query($sql, $link) or die ("(edit_user.inc.php) Error, Line 174: ".mysql_error()) )
 										{
 										$saved_settings_successfull = 1;
 										}
@@ -215,6 +217,7 @@
 						$r_delete = $user['r_delete'];
 						$r_edit = $user['r_edit'];
 						$r_spam = $user['r_spam'];
+						$r_edit_smilies = $user['r_edit_smilies'];
 
 						if($_SESSION['ID'] == $userID)
 							{
@@ -235,6 +238,7 @@
 						if ($r_delete == 0) { $selected_r_delete_0 = " selected"; $selected_r_delete_1 = NULL; } else { $selected_r_delete_0 = NULL; $selected_r_delete_1 = " selected"; }
 						if ($r_edit == 0) { $selected_r_edit_0 = " selected"; $selected_r_edit_1 = NULL; } else { $selected_r_edit_0 = NULL; $selected_r_edit_1 = " selected"; }
 						if ($r_spam == 0) { $selected_r_spam_0 = " selected"; $selected_r_spam_1 = NULL; } else { $selected_r_spam_0 = NULL; $selected_r_spam_1 = " selected"; }
+						if ($r_edit_smilies == 0) { $selected_r_edit_smilies_0 = " selected"; $selected_r_edit_smilies_1 = NULL; } else { $selected_r_edit_smilies_0 = NULL; $selected_r_edit_smilies_1 = " selected"; }
 
 						$page_edit_user_single = preg_replace("/\{TEMPLATE_ERRORMESSAGE\}/", $content_errormessage, $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{ERRORMESSAGE\}/", $errormessage, $page_edit_user_single);
@@ -253,6 +257,7 @@
 						$page_edit_user_single = preg_replace("/\{LANG_R_DELETE\}/", $lang['r_delete'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_R_EDIT\}/", $lang['r_edit'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_R_SPAM\}/", $lang['r_spam'], $page_edit_user_single);
+						$page_edit_user_single = preg_replace("/\{LANG_R_EDIT_SMILIES\}/", $lang['r_edit_smilies'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_EDIT_USER_CAPTION_PASSWORD\}/", $lang['edit_user_caption_password'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_NEW_PASSWORD_1\}/", $lang['new_password_1'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_NEW_PASSWORD_2\}/", $lang['new_password_2'], $page_edit_user_single);
@@ -283,6 +288,8 @@
 						$page_edit_user_single = preg_replace("/\{SELECTED_R_EDIT_1\}/", $selected_r_edit_1, $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{SELECTED_R_SPAM_0\}/", $selected_r_spam_0, $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{SELECTED_R_SPAM_1\}/", $selected_r_spam_1, $page_edit_user_single);
+						$page_edit_user_single = preg_replace("/\{SELECTED_R_EDIT_SMILIES_0\}/", $selected_r_edit_smilies_0, $page_edit_user_single);
+						$page_edit_user_single = preg_replace("/\{SELECTED_R_EDIT_SMILIES_1\}/", $selected_r_edit_smilies_1, $page_edit_user_single);
 
 						$page_edit_user_single = preg_replace("/\{FORM_ACTION\}/", "admin.php?action=editusers&amp;mode=edit&amp;id=".$userID.$sid, $page_edit_user_single);
 
@@ -309,6 +316,7 @@
 					$_POST['r_delete'] = cleanstr($_POST['r_delete']);
 					$_POST['r_edit'] = cleanstr($_POST['r_edit']);
 					$_POST['r_spam'] = cleanstr($_POST['r_spam']);
+					$_POST['r_edit_smilies'] = cleanstr($_POST['r_edit_smilies']);
 					$_POST['old_password'] = cleanstr($_POST['old_password']);
 					$_POST['new_password_1'] = cleanstr($_POST['new_password_1']);
 					$_POST['new_password_2'] = cleanstr($_POST['new_password_2']);
@@ -358,6 +366,7 @@
 										`r_delete`,
 										`r_edit`,
 										`r_spam`,
+										`r_edit_smilies`,
 										`logged_out`
 									) VALUES (
 										'".$_POST['name']."',
@@ -371,10 +380,11 @@
 										'".$_POST['r_delete']."',
 										'".$_POST['r_edit']."',
 										'".$_POST['r_spam']."',
+										'".$_POST['r_edit_smilies']."',
 										'".$_POST['logged_out']."'
 									);";
 
-						@mysql_query($sql, $link) or die ("(edit_user.inc.php) Error, line 367: ".mysql_error());
+						@mysql_query($sql, $link) or die ("(edit_user.inc.php) Error, line 387: ".mysql_error());
 						
 						if(!isset($_POST['send_account_data'])) { $_POST['send_account_data'] = 0; }
 
@@ -426,6 +436,7 @@
 					$page_edit_user_adduser = preg_replace("/\{LANG_R_DELETE\}/", $lang['r_delete'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_R_EDIT\}/", $lang['r_edit'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_R_SPAM\}/", $lang['r_spam'], $page_edit_user_adduser);
+					$page_edit_user_adduser = preg_replace("/\{LANG_R_EDIT_SMILIES\}/", $lang['r_edit_smilies'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_EDIT_USER_CAPTION_PASSWORD\}/", $lang['edit_user_caption_password'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_NEW_PASSWORD_1\}/", $lang['new_password_1'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_NEW_PASSWORD_2\}/", $lang['new_password_2'], $page_edit_user_adduser);
@@ -447,6 +458,7 @@
 					if ($_POST['r_delete'] == 0) { $selected_r_delete_0 = " selected"; $selected_r_delete_1 = NULL; } else { $selected_r_delete_0 = NULL; $selected_r_delete_1 = " selected"; }
 					if ($_POST['r_edit'] == 0) { $selected_r_edit_0 = " selected"; $selected_r_edit_1 = NULL; } else { $selected_r_edit_0 = NULL; $selected_r_edit_1 = " selected"; }
 					if ($_POST['r_spam'] == 0) { $selected_r_spam_0 = " selected"; $selected_r_spam_1 = NULL; } else { $selected_r_spam_0 = NULL; $selected_r_spam_1 = " selected"; }
+					if ($_POST['r_edit_smilies'] == 0) { $selected_r_edit_smilies_0 = " selected"; $selected_r_edit_smilies_1 = NULL; } else { $selected_r_edit_smilies_0 = NULL; $selected_r_edit_smilies_1 = " selected"; }
 
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_NAME\}/", $_POST['name'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_EMAIL\}/", $_POST['email'], $page_edit_user_adduser);
@@ -466,6 +478,8 @@
 					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_EDIT_1\}/", $selected_r_edit_1, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_SPAM_0\}/", $selected_r_spam_0, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_SPAM_1\}/", $selected_r_spam_1, $page_edit_user_adduser);
+					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_EDIT_SMILIES_0\}/", $selected_r_edit_smilies_0, $page_edit_user_adduser);
+					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_EDIT_SMILIES_1\}/", $selected_r_edit_smilies_1, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_NEW_PASSWORD_1\}/", $save_pw, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_NEW_PASSWORD_2\}/", $save_pw, $page_edit_user_adduser);
 
