@@ -19,7 +19,7 @@
 	*/
 
 	// ============================ //
-	// lang_admin.php - Italian 1.1 //
+	// lang_admin.php - Italian 1.2 //
 	// ============================ //
 	//
 	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
@@ -124,6 +124,7 @@
 	$lang['delete'] = "Cancella il post";
 	$lang['edit'] = "Modifica il post";
 	$lang['spam'] = "Spam entries";
+	$lang['edit_smilies'] = "Edit smilies";
 	$lang['users'] = "Amministrazione utenti";
 	$lang['stats'] = "Statistics";
 	$lang['license'] = "Licenza";
@@ -168,6 +169,9 @@
 	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
 	$lang['edit_akismet_api'] = "Akismet API Key:";
 	$lang['edit_akismet_mark_as_spam'] = "Spam marking:";
+	$lang['edit_time_lock'] = "Sign lock:";
+	$lang['edit_time_lock_value'] = "Minimum time for sign lock:";
+	$lang['edit_time_lock_maxtime'] = "Maximum time for sign lock:";
 	$lang['edit_user_notification'] = "Notifica utente:";
 	$lang['edit_user_show_email'] = "Usermail presso il guestbook:";
 	$lang['edit_session_timeout'] = "timeout della sesseione:";
@@ -206,11 +210,14 @@
 	$lang['edit_expl_smileys'] = "Permette all'utente di aggiungere smileys.";
 	$lang['edit_expl_captcha'] = "Se attivato un codice di verifica deve essere immesso per aggiungere un nuovo post o spedire una mail ad un utente.";
 	$lang['edit_expl_captcha_method'] = "You can choose between a securitycode, or a mathematic formula the user has to solve.";
-	$lang['edit_expl_akismet_plugin'] = "Akismet is an external anti-spam-service, that checks new entries on spam. The akismet-plugin can be downloaded at <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet is an external anti-spam-service, that checks new entries on spam. The akismet-plugin can be downloaded at <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.<br><br><b>ATTENTION: With using the plugin 'akismet' you accept the transmission of data to a server in the United States of America. If you don't comply with that circumstance you MUST NOT USE 'Akismet'. Also your users have to agree with that if you activate the plugin.</b>";
 	$lang['edit_expl_akismet_api'] = "In order to use Akismet you need an <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a>. Sign in for free and enter it here after registration.";
 	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet is installed!</span>";
 	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet is NOT installed!</span>";
 	$lang['edit_expl_akismet_mark_as_spam'] = "If this option is enabled, positive Akismet entries are marked as spam and appear in the administration panel so you can check them for yourself and decide what to do with.";
+	$lang['edit_expl_time_lock'] = "If this option is enabled, a counter that prevents sending the formular too fast runs in the background of a new entry. If the user is too fast with his entry, a message appears that tells him how many seconds he have to wait, until he can sign the guestbook.";
+	$lang['edit_expl_time_lock_value'] = "Minimum time a user has to wait to send the formular.";
+	$lang['edit_expl_time_lock_maxtime'] = "Maximum time a user has the chance to sign the guestbook. If it takes too long, the counter restarts.";
 	$lang['edit_expl_user_notification'] = "Permette all'utente di decidere se sarà avvertito via email se il suo post sarà attivato.";
 	$lang['edit_expl_user_show_email'] = "Permette all'utente di decidere se il suo indirizzo eMail verrà mostrato nel guestbook oppure no. Se disabilita la checkbox nessuno all'infuori dell'amministratore potrà spedirgli una mail.";
 	$lang['edit_expl_session_timeout'] = "Un ut3ente inattivo verrà automaticamente sloggato se questo periodo scade. Espresso in <b>secondi</b>. Il valore dev'essere maggiore o uguale a (>=) <b>60</b>.";
@@ -241,6 +248,18 @@
 	$lang['user_show_email'] = "Mostra gli indirizzi eMail nel guestbook:";
 	$lang['comment'] = "Commenti:";
 
+	// smilies.inc.php
+	$lang['add_smilies_descr'] = "Here you can edit or remove smilies.<br><br>All smilies have to be in the folder <b>'images/smilies/'</b> in the root directory of the guestbook. You only have to put the filename into the <b>empty textbox</b> and then press <b>save</b>.<br><br><b>Please notice: If you change existing smilies or place holders that were already used in entries, then they cannot be correctly replaced any more! You have to edit these entries by hand.</b>";
+	$lang['smiley_path'] = "Filename";
+	$lang['smiley_replacement'] = "Place holder";
+	$lang['add_new_smiley'] = "Add smiley";
+	$lang['delete_checked_smilies'] = "... remove from list, keep unchecked";
+	$lang['keep_checked_smilies'] = "... keep, remove unchecked";
+	$lang['smiley_width'] = "Width";
+	$lang['smiley_height'] = "Height";
+	$lang['smilies'] = "Smilies";
+	$lang['checked_smilies'] = "Checked smilies ...";
+
 	// edit_user.php
 	$lang['user_is_active'] = "L'utente è attivo:";
 	$lang['r_user_type'] = "L'utente è:";
@@ -250,6 +269,7 @@
 	$lang['r_delete'] = "Cancella i post:";
 	$lang['r_edit'] = "Modifica i post:";
 	$lang['r_spam'] = "Manage spam:";
+	$lang['r_edit_smilies'] = "Edit smilies";
 	$lang['old_password'] = "La tua password corrente:";
 	$lang['new_password_1'] = "Nuova password:";
 	$lang['new_password_2'] = "Digita di nuovo:";
