@@ -18,9 +18,9 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// =========================== //
-	// lang_admin.php - German 1.2 //
-	// =========================== //
+	// ===================================== //
+	// lang_admin.php - Schweizerdeutsch 1.3 //
+	// ===================================== //
 	//
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
@@ -34,12 +34,12 @@
 	$lang['moderator'] = "Moderator";
 
 	// login.php
-	$lang['title'] = "MGB {MGB_VERSION} - Administration";	
+	$lang['title'] = "MGB {MGB_VERSION} - Administration";
 	$lang['login_username'] = "Benutzername:";
 	$lang['login_password'] = "Passwort:";
 	$lang['login_lostpassword'] = "Ich habe mein Passwort vergessen";
 	$lang['login'] = "Anmelden";
-	$lang['logout'] = "Abmelden";	
+	$lang['logout'] = "Abmelden";
 	$lang['login_ok'] = "Herzlich Willkommen <b>{SESSION_USERNAME}</b>.";
 	$lang['logged_in'] = "Sie sind angemeldet als <b>{SESSION_USERNAME}</b>";
 	$lang['logged_out'] = "Geben Sie bitte Ihren Benutzernamen und Ihr Passwort ein um sich anzumelden.";
@@ -122,6 +122,7 @@
 	$lang['delete'] = "Eintrag l&ouml;schen";
 	$lang['edit'] = "Eintrag editieren";
 	$lang['spam'] = "Spam-Eintr&auml;ge";
+	$lang['edit_smilies'] = "Smilies bearbeiten";
 	$lang['users'] = "Benutzerverwaltung";
 	$lang['stats'] = "Statistik";
 	$lang['license'] = "Lizenz";
@@ -245,6 +246,18 @@
 	$lang['user_show_email'] = "Zeige email im G&auml;stebuch an:";
 	$lang['comment'] = "Kommentar:";
 
+	// smilies.inc.php
+	$lang['add_smilies_descr'] = "Hier k&ouml;nnen Sie bestehende Smilies &auml;ndern, oder neue hinzuf&uuml;gen.<br><br>Alle Smilies die hinzugef&uuml;gt werden sollen, m&uuml;ssen sich im Ordner <b>'images/smilies/'</b> im Hauptverzeichnis des G&auml;stebuches befinden. Sie m&uuml;ssen also nur den Dateinamen angeben. Benutzen Sie dazu bitte das <b>leere Feld</b> und dr&uuml;cken dann <b>Speichern</b>.<br><br><b>Bitte beachten Sie, dass wenn Sie bestehende Platzhalter oder Smilies &auml;ndern bzw. l&ouml;schen, die in Eintr&auml;gen bereits verwendet wurden, diese nicht mehr korrekt angezeigt werden k&ouml;nnen! Sie m&uuml;ssen diese Eintr&auml;ge dann per Hand editieren.</b>";
+	$lang['smiley_path'] = "Dateiname";
+	$lang['smiley_replacement'] = "Platzhalter";
+	$lang['add_new_smiley'] = "Smiley hinzuf&uuml;gen";
+	$lang['delete_checked_smilies'] = "... aus Liste entfernen, unmarkierte behalten";
+	$lang['keep_checked_smilies'] = "... in Liste behalten, unmarkierte entfernen";
+	$lang['smiley_width'] = "Breite";
+	$lang['smiley_height'] = "H&ouml;he";
+	$lang['smilies'] = "Smilies";
+	$lang['checked_smilies'] = "Markierte Smilies ...";
+
 	// edit_user.php
 	$lang['user_is_active'] = "Benutzer ist aktiv:";
 	$lang['r_user_type'] = "Benutzer ist:";
@@ -254,6 +267,7 @@
 	$lang['r_delete'] = "Eintr&auml;ge l&ouml;schen:";
 	$lang['r_edit'] = "Eintr&auml;ge editieren:";
 	$lang['r_spam'] = "Spam verwalten:";
+	$lang['r_edit_smilies'] = "Smilies bearbeiten";
 	$lang['old_password'] = "Ihr aktuelles Passwort:";
 	$lang['new_password_1'] = "Passwort:";
 	$lang['new_password_2'] = "Passwort best&auml;tigen:";
