@@ -19,7 +19,7 @@
 	*/
 
 	// ============================================== //
-	// lang_admin.php - Turkish 1.0 by Mustafa Dündar //
+	// lang_admin.php - Turkish 1.1 by Mustafa Dündar //
 	// ============================================== //
 	//
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
@@ -122,6 +122,7 @@
 	$lang['delete'] = "Kayýt Sil";
 	$lang['edit'] = "Kayýt düzenle";
 	$lang['spam'] = "Spam olarak işaretlenmiş Girişler";
+	$lang['edit_smilies'] = "Edit smilies";
 	$lang['users'] = "Kullanýcý yönetimi";
 	$lang['stats'] = "Ýstatistik";
 	$lang['license'] = "Lisans";
@@ -207,7 +208,7 @@
 	$lang['edit_expl_smileys'] = "Smiles eklemesini kullanýcýya saðlar.";
 	$lang['edit_expl_captcha'] = "Bir Kullanýcý yeni bir giriþ ve e-Posta yazý yazmasýný etkinleþtirmesi için bir güvenlik kodu vermesi gerekir.";
 	$lang['edit_expl_captcha_method'] = "Kullanýcý bir aritmetik problemi çözmek için bir güvenlik kodu veya matematiksel bir Captcha arasýnda seçim yapabilirsiniz.";
-	$lang['edit_expl_akismet_plugin'] = "Akismet harici bir hizmettir, yeni giriþlerde spam kontrol eder ve olumlu bir sonuçta giriþi yazar. Akismet eklentisi <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet eklentisi'>http://www.m-gb.org/</a> indirilir.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet harici bir hizmettir, yeni giriþlerde spam kontrol eder ve olumlu bir sonuçta giriþi yazar. Akismet eklentisi <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet eklentisi'>http://www.m-gb.org/</a> indirilir.<br><br><b>ATTENTION: With using the plugin 'akismet' you accept the transmission of data to a server in the United States of America. If you don't comply with that circumstance you MUST NOT USE 'Akismet'. Also your users have to agree with that if you activate the plugin.</b>";
 	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet yüklenmiþtir!</span>";
 	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet yüklenmemiþtir!</span>";
 	$lang['edit_expl_akismet_api'] = "Akismet i kullanabilmek için, Akismet-eklentisi <a href='http://akismet.com/signup/#free' title='Akismet API Anahtar'>API Key</a> lazýmdýr. Burada kayýt ver.";
@@ -245,7 +246,19 @@
 	$lang['user_show_email'] = "Ziyaretçi Defterindeki e-Posta larý göster:";
 	$lang['comment'] = "Yorum:";
 
-	// edit_user.php
+	// smilies.inc.php
+	$lang['add_smilies_descr'] = "Here you can edit or remove smilies.<br><br>All smilies have to be in the folder <b>'images/smilies/'</b> in the root directory of the guestbook. You only have to put the filename into the <b>empty textbox</b> and then press <b>save</b>.<br><br><b>Please notice: If you change existing smilies or place holders that were already used in entries, then they cannot be correctly replaced any more! You have to edit these entries by hand.</b>";
+	$lang['smiley_path'] = "Filename";
+	$lang['smiley_replacement'] = "Place holder";
+	$lang['add_new_smiley'] = "Add smiley";
+	$lang['delete_checked_smilies'] = "... remove from list, keep unchecked";
+	$lang['keep_checked_smilies'] = "... keep, remove unchecked";
+	$lang['smiley_width'] = "Width";
+	$lang['smiley_height'] = "Height";
+	$lang['smilies'] = "Smilies";
+	$lang['checked_smilies'] = "Checked smilies ...";
+
+	// edit_user.inc.php
 	$lang['user_is_active'] = "Kullanýcý aktif:";
 	$lang['r_user_type'] = "Kullanýcý:";
 	$lang['r_settings'] = "Yapýlandýrma deðiþikliði:";
@@ -254,6 +267,7 @@
 	$lang['r_delete'] = "Girdileri Silin:";
 	$lang['r_edit'] = "Girdileri düzenleyin:";
 	$lang['r_spam'] = "Spam yönetmek:";
+	$lang['r_edit_smilies'] = "Edit smilies";
 	$lang['old_password'] = "Mevcut Þifre:";
 	$lang['new_password_1'] = "Þifre:";
 	$lang['new_password_2'] = "Þifre onaylayýnýz:";
